==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta2StatefulSetUpdateStrategyFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta2StatefulSetUpdateStrategyFluentImpl<A extends V1beta2StatefulSetUpdateStrategyFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta2StatefulSetUpdateStrategyFluent<A>{

    private V1beta2RollingUpdateStatefulSetStrategyBuilder rollingUpdate;
    private String type;

    public V1beta2StatefulSetUpdateStrategyFluentImpl(){
    }
    public V1beta2StatefulSetUpdateStrategyFluentImpl(V1beta2StatefulSetUpdateStrategy instance){
            this.withRollingUpdate(instance.getRollingUpdate());

            this.withType(instance.getType());

    }

    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1beta2RollingUpdateStatefulSetStrategy getRollingUpdate(){
            return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public V1beta2RollingUpdateStatefulSetStrategy buildRollingUpdate(){
            return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public A withRollingUpdate(V1beta2RollingUpdateStatefulSetStrategy rollingUpdate){
            _visitables.remove(this.rollingUpdate);
            if (rollingUpdate!=null){ this.rollingUpdate= new V1beta2RollingUpdateStatefulSetStrategyBuilder(rollingUpdate); _visitables.add(this.rollingUpdate);} return (A) this;
    }

    public Boolean hasRollingUpdate(){
            return this.rollingUpdate != null;
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate(){
            return new RollingUpdateNestedImpl();
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1beta2RollingUpdateStatefulSetStrategy item){
            return new RollingUpdateNestedImpl(item);
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate(){
            return withNewRollingUpdateLike(getRollingUpdate());
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate(){
            return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new V1beta2RollingUpdateStatefulSetStrategyBuilder().build());
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1beta2RollingUpdateStatefulSetStrategy item){
            return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta2StatefulSetUpdateStrategyFluentImpl that = (V1beta2StatefulSetUpdateStrategyFluentImpl) o;
            if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }


    public class RollingUpdateNestedImpl<N> extends V1beta2RollingUpdateStatefulSetStrategyFluentImpl<V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>> implements V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta2RollingUpdateStatefulSetStrategyBuilder builder;
    
            RollingUpdateNestedImpl(V1beta2RollingUpdateStatefulSetStrategy item){
                    this.builder = new V1beta2RollingUpdateStatefulSetStrategyBuilder(this, item);
            }
            RollingUpdateNestedImpl(){
                    this.builder = new V1beta2RollingUpdateStatefulSetStrategyBuilder(this);
            }
    
    public N and(){
            return (N) V1beta2StatefulSetUpdateStrategyFluentImpl.this.withRollingUpdate(builder.build());
    }
    public N endRollingUpdate(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta2StatefulSetUpdateStrategyFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1beta2StatefulSetUpdateStrategyFluentImpl<A extends V1beta2StatefulSetUpdateStrategyFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta2StatefulSetUpdateStrategyFluent<A>{

    private V1beta2RollingUpdateStatefulSetStrategyBuilder rollingUpdate;
    private String type;

    public V1beta2StatefulSetUpdateStrategyFluentImpl(){
    }
    public V1beta2StatefulSetUpdateStrategyFluentImpl(V1beta2StatefulSetUpdateStrategy instance){
            this.withRollingUpdate(instance.getRollingUpdate());

            this.withType(instance.getType());

    }

    
/**
 * This method has been deprecated, please use method buildRollingUpdate instead.
 * @return The buildable object.
 */
@Deprecated public V1beta2RollingUpdateStatefulSetStrategy getRollingUpdate(){
            return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public V1beta2RollingUpdateStatefulSetStrategy buildRollingUpdate(){
            return this.rollingUpdate!=null?this.rollingUpdate.build():null;
    }

    public A withRollingUpdate(V1beta2RollingUpdateStatefulSetStrategy rollingUpdate){
            _visitables.get("rollingUpdate").remove(this.rollingUpdate);
            if (rollingUpdate!=null){ this.rollingUpdate= new V1beta2RollingUpdateStatefulSetStrategyBuilder(rollingUpdate); _visitables.get("rollingUpdate").add(this.rollingUpdate);} return (A) this;
    }

    public Boolean hasRollingUpdate(){
            return this.rollingUpdate != null;
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdate(){
            return new RollingUpdateNestedImpl();
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> withNewRollingUpdateLike(V1beta2RollingUpdateStatefulSetStrategy item){
            return new RollingUpdateNestedImpl(item);
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editRollingUpdate(){
            return withNewRollingUpdateLike(getRollingUpdate());
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdate(){
            return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): new V1beta2RollingUpdateStatefulSetStrategyBuilder().build());
    }

    public V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<A> editOrNewRollingUpdateLike(V1beta2RollingUpdateStatefulSetStrategy item){
            return withNewRollingUpdateLike(getRollingUpdate() != null ? getRollingUpdate(): item);
    }

    public String getType(){
            return this.type;
    }

    public A withType(String type){
            this.type=type; return (A) this;
    }

    public Boolean hasType(){
            return this.type != null;
    }

    public A withNewType(String arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuilder arg1){
            return (A)withType(new String(arg1));
    }

    public A withNewType(StringBuffer arg1){
            return (A)withType(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta2StatefulSetUpdateStrategyFluentImpl that = (V1beta2StatefulSetUpdateStrategyFluentImpl) o;
            if (rollingUpdate != null ? !rollingUpdate.equals(that.rollingUpdate) :that.rollingUpdate != null) return false;
            if (type != null ? !type.equals(that.type) :that.type != null) return false;
            return true;
    }


    public class RollingUpdateNestedImpl<N> extends V1beta2RollingUpdateStatefulSetStrategyFluentImpl<V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>> implements V1beta2StatefulSetUpdateStrategyFluent.RollingUpdateNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1beta2RollingUpdateStatefulSetStrategyBuilder builder;
    
            RollingUpdateNestedImpl(V1beta2RollingUpdateStatefulSetStrategy item){
                    this.builder = new V1beta2RollingUpdateStatefulSetStrategyBuilder(this, item);
            }
            RollingUpdateNestedImpl(){
                    this.builder = new V1beta2RollingUpdateStatefulSetStrategyBuilder(this);
            }
    
    public N and(){
            return (N) V1beta2StatefulSetUpdateStrategyFluentImpl.this.withRollingUpdate(builder.build());
    }
    public N endRollingUpdate(){
            return and();
    }

}


}
